NdefMessage class final

The NDEF message consisting of a list of records.

Constructors

NdefMessage({required List<NdefRecord> records})
Constructs an NDEF message from a list of records.
const
NdefMessage.decode(Uint8List bytes)
Decodes an NdefMessage from its NDEF binary wire format.
factory

Properties

byteLength int
The length of this message in bytes, as encoded without chunking.
no setter
hashCode int
The hash code for this object.
no setteroverride
records List<NdefRecord>
The list of records for the message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode({int? maxChunkPayloadLength}) Uint8List
Encodes this message into its NDEF binary wire format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override