byteLength property

int get byteLength

The length of this message in bytes, as encoded without chunking.

This matches the length of encode called without maxChunkPayloadLength. Chunking may increase the encoded length: shorter payload length fields can offset the extra chunk headers.

Implementation

int get byteLength {
  return records.fold(0, (p, e) => p + e.byteLength);
}